[−][src]Struct dipstick::CancelGuard

pub struct CancelGuard<C: Cancel> { /* fields omitted */ }

A guard canceling the inner handle when dropped.

See Cancel::into_guard to create it.

Implementations

impl<C: Cancel> CancelGuard<C>[src]

pub fn disarm(self) -> C[src]

Disarms the guard.

This disposes of the guard without performing the cancelation. This is similar to calling forget on it, but doesn't leak resources, while forget potentially could.